@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef UTILS_SLIDE_H
-#define UTILS_SLIDE_H
+#pragma once
 
 #include <algorithm>
 
@@ -33,5 +32,3 @@ void slide_one(Iterator f, Iterator p)
 
 } // namespace utils
 } // namespace kamd
-
-#endif // UTILS_SLIDE_H
